#===========================================================
#
# Procedure: cn_auslosung
#
# Purpose: Auslosung
#               
# Preconditions:
#  Mannschaften sind eingegeben. Turnier ist geffnet.
#  Turnier ist nicht ausgelost.
#
# Postconditions:
#  Die Paarungen werden anhand der Turniertabellen bestimmt.
#  Die Daten werden pro Runde in eine Datei gespeichert
#  Name : r.<runde>
#  Format: heim gast Spielflag HBrettPkt HMannPkt ABrettpkt AMannPkt
#  Wenn Heim oder Gast = 0, dann spielfrei.
#
# Globals:  turdir
#           auslosungfile
#           wettkampffile
#
# Returns: 0 = success
#          1 = failure
#=============================================================
proc cn_auslosung { Tid } {
   # Globals
   global turdir
   global auslosungfile
   global wettkampffile
                      
   # Holen der Mannschaften
   set s [db_mannschaft_selall $Tid mannschaften]

   set MAnzahl [array size mannschaften]
   set TlnAnzahl $MAnzahl
   if { ($TlnAnzahl & 1 ) == 1 } {
      incr TlnAnzahl
      set mannschaften($TlnAnzahl) [list 0 "spielfrei " "-- "]
   }
   set HalbAnzahl [expr $TlnAnzahl/2]
   set Anzahl [expr $TlnAnzahl-1]
   for {set r 1} { $r < $TlnAnzahl} { incr r} {
      set fa [open $turdir/$Tid/$wettkampffile.$r w]
      set a [Begegnung 1 $r $TlnAnzahl]
      set b $TlnAnzahl
#      set a [Begegnung mannschaften 1 $r $TlnAnzahl]
#      set b [lindex $mannschaften($TlnAnzahl) 0]

#--------------------------------------------------------
# Changed:  5-MAY-1997
# Name: G.Niklaus
# Reason: Beruecksichtigung ungerader Anzahl Mannschaften
#-------------------------------------------------------

      # Erster Wettkampf der Runde
      if { $MAnzahl == $TlnAnzahl } {
         if { ($r & 1) != 0 } {
            puts $fa [list $a $b 0 0 0 0 0]
         } else {
            puts $fa [list $b $a 0 0 0 0 0]
         }
      }

      # Weitere Wettkmpfe
      for { set i 2 } { $i <= $HalbAnzahl } { incr i} {
#         set a [Begegnung mannschaften $i $r $TlnAnzahl]
#         set b [Begegnung mannschaften [expr $TlnAnzahl-$i+1] $r $TlnAnzahl]
         set a [Begegnung $i $r $TlnAnzahl]
         set b [Begegnung [expr $TlnAnzahl-$i+1] $r $TlnAnzahl]
         puts $fa [list $a $b 0 0 0 0 0]
      }
      close $fa
   }              

   set rundenerr [db_runde_selall $Tid runden]
   for { set r 1 } { $r < $TlnAnzahl } { incr r } {
      if { [info exists runden($r)] } {
         set rundenneu($r) $runden($r)
      } else {
         set rundenneu($r) " "
      }
   }
   set s [db_runde_store $Tid rundenneu]
   set s [ui_runde_display rundenneu]
 
# Alle Runden = TlnAnzahl - 1 !

    
   ui_warning "Auslosung" "Auslosung ist durchgefhrt und gespeichert."
   return 0

}

#===========================================================
#
# Procedure: cn_spielplan_display
#
# Purpose: Generieren und Anzeigen des Spielplans.
#
# Preconditions:
#  Turnier ist ausgelost, Paarungen liegen fest.
#
# Postconditions:
#  Es wird ein Terminplan erstellt, der die Begegnungen der einzelnen
#  Runden enthlt.
#
# Returns: 0 = success
#
#=============================================================

proc cn_spielplan_display { } {

   # Holen und prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, kein Spielplan mglich."
      return
   }

   # Erstellen des Spielplanes in eine Datei
   set s [cn_spielplan $Tid]
   if {$s} { ui_warning $Tname "Kein Spielplan erstellt"; return }

   set s [ui_spielplan_display $Tid]
   return
}

#===========================================================
#
# Procedure: cn_spielplan
#
# Purpose: Generieren des Spielplans.
#
# Preconditions:
#  Turnier ist ausgelost, Paarungen liegen fest. Turnier ist offen
#
# Postconditions:
#  Der Spielplan wird in eine Datei geschrieben.
#
# Globals
#  turdir
#  spielplanfile
#
# Returns: 0 = success
#          1 = failure
#=============================================================
#
# 15-JUL-1996: ni
#              Rundentermine optional
#=============================================================

proc cn_spielplan { Tid } {
   # Globals 
   global turdir
   global spielplanfile
   global datumcmd

   set datum [eval $datumcmd]

   # Holen der Turnierdaten
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   if {$s} { return 1 }; # Fehler!

   # Holen der Mannschaftsdaten
   set s [db_mannschaft_selall $Tid mannschaften]
   if {$s} { return 1 }; # Fehler!    

   # Holen der vorhandenen Runden in ein Array
   set rundenerr [db_runde_selall $Tid runden]
#   if {$rundenerr} { return 1 }; # Fehler!

   set dash "-------------------------------------------------------------------------"
   set curdir [pwd]
   cd $turdir
   cd $Tid
   set fb [open $spielplanfile w]
   puts $fb "Spielplan - $Tname ($Spielleiter(globaltid))"
   puts $fb "Datum der Erstellung: $datum"
#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: 3-Punkte-Wertung
#
#-------------------------------------------------------
   if { [string trim $Spielleiter(Siegpunkte)] != "2" } {
      puts $fb "$Spielleiter(Siegpunkte)-Punkte-Wertung"   
   }
   puts $fb $dash
   # Ausgabe Spielleiter
   puts $fb "Spielleiter: $Spielleiter(Name)"
   puts $fb "             $Spielleiter(Strasse)"
   puts $fb "             $Spielleiter(Wohnort)"
   puts $fb "             Telefon: $Spielleiter(Telefon)"
   puts $fb "             FAX    : $Spielleiter(FAX)"
   puts $fb "             Mail   : $Spielleiter(Mail)"
   puts $fb $dash

   puts $fb "Teilnehmende Mannschaften   Heimspieltag"
   foreach i [lsort -integer [array names mannschaften]] {
      set temp [format "%4s : %-20s: %-20s" $i [lindex $mannschaften($i) 1] [lindex $mannschaften($i) 2]]
      puts $fb $temp
   }     
   puts $fb $dash

   # Bestimmen der zu spielenden Runden
   set MAnzahl [array size mannschaften]
   set TlnAnzahl $MAnzahl
   if { ($TlnAnzahl & 1 ) == 1 } {
      incr TlnAnzahl
      set mannschaften($TlnAnzahl) [list 0 "spielfrei " "-- "]
   }

#--------------------------------------------------------
# Changed:  5-MAY-1997
# Name: G.Niklaus
# Reason: Ausgabe der gespielten Ergebnisse
#-------------------------------------------------------
#--------------------------------------------------------
# Changed: 27-MAY-1997
# Name: G.Niklaus
# Reason: Angabe von kampflosen Wettkaempfen
#-------------------------------------------------------

   # Ausgabe der zu spielenden Runden
   for {set r 1} { $r < $TlnAnzahl} { incr r} {
      set s [db_runde_load $Tid $r wettkampf]
      puts $fb ""
      if {$rundenerr} {set runden($r) " "}             
      puts $fb "Runde $r : $runden($r)"
      foreach k [lsort -integer [array names wettkampf]] {
         set heim [lindex $wettkampf($k) 0]
         set gast [lindex $wettkampf($k) 1]
         set termin [lindex $mannschaften($heim) 2]
         if { [lindex $wettkampf($k) 2] == 1} then {
            set erg [format "%-3s - %-3s    " \
               [lindex $wettkampf($k) 3] [lindex $wettkampf($k) 5]] 
         } elseif { [lindex $wettkampf($k) 2] == 2 } then {
            set erg [format "%-3s - %-3s kl " \
               [lindex $wettkampf($k) 3] [lindex $wettkampf($k) 5]] 
         } elseif { [lindex $wettkampf($k) 2] == 3 } then {
            set erg [format "%-3s - %-3s me " \
               [lindex $wettkampf($k) 3] [lindex $wettkampf($k) 5]] 
         } else { set erg "___ - ___    " } 
         set temp [format "%-16s : %-22s %12s %-22s" $termin \
            [lindex $mannschaften($heim) 1] $erg [lindex $mannschaften($gast) 1]]
         puts $fb $temp
      }           
   }         

#--------------------------------------------------------
# Changed: 29-SEP-1997
# Name: G.Niklaus
# Reason: Einbeziehen des Spielplan-Anhanges
#
#-------------------------------------------------------

   set s [db_spielplan_anhang_selall $Tid Spielplan_Anhang Dateiname]
   puts $fb $dash
   puts $fb $Spielplan_Anhang

   close $fb          
   return 0
}

#===========================================================
#
# Procedure: cn_runde_eingabe
#
# Purpose: Eingeben des Ergebnisses einer Runde
#
# Preconditions:
#  Turnier ist ausgelost, Paarungen liegen fest. Turnier ist offen.
#  Runde ist selektiert.
#
# Postconditions:
#  Die Ergebnisse der selektierten Runde werden aufgeblendet und die
#  Einzelergebnisse knnen eingegeben werden.
#
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_runde_eingabe { } {

   # Prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet!"
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, keine Rundeneingabe mglich!"
      return
   }

   # Holen der selektierten Runde  
   set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Aufblenden der ausgewhlten Runde, Eingabe
   set s [ui_runde_eingabe $Tid $Runde]

   return 0
}

#===========================================================
#
# Procedure: cn_kreuztabelle_display
#
# Purpose: Generieren und Anzeigen der Kreuztabelle.
#
# Preconditions:
#  Turnier ist ausgelost, Paarungen liegen fest.
#
# Postconditions:
#  Es wird eine Kreuztabelle angezeigt, in der die einzelnen Paarungen
#  jeweils direkt mit der Maus aufgerufen werden knnen.
#
# Returns: 0 = success
#
#=============================================================

proc cn_kreuztabelle_display { } {

   # Holen und prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return                          
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, kein Spielplan mglich."
      return
   }

   # Erstellen der Kreuztabelle
   set s [cn_kreuztabelle $Tid]
   if {$s} { ui_warning $Tname "Keine Kreuztabelle erstellt"; return }

   set s [ui_kreuztabelle_display $Tid]
   return
}

#===========================================================
#
# Procedure: cn_kreuztabelle
#
# Purpose: Generieren der Kreuztabelle
#
# Preconditions:
#  Turnier ist ausgelost, Paarungen liegen fest. Turnier ist offen
#
# Postconditions:
#  Die Kreuztabelle wird erstellt, die Daten in globale Variable 
#  geschrieben
#
# Globals
#  turdir
#  spielplanfile
#
# Returns: 0 = success
#          1 = failure
#=============================================================
#
# 15-JUL-1996: ni
#              Rundentermine optional
#=============================================================

proc cn_kreuztabelle { Tid } {
   # Globals 
   global turdir
   global datumcmd
   global wettkaempfe

   set datum [eval $datumcmd]
   catch {unset wettkaempfe}

   # Holen der Turnierdaten
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   if {$s} { return 1 }; # Fehler!

   # Holen der Mannschaftsdaten
   set s [db_mannschaft_selall $Tid mannschaften]
   if {$s} { return 1 }; # Fehler!    

   # Holen der vorhandenen Runden in ein Array
   set rundenerr [db_runde_selall $Tid runden]
#   if {$rundenerr} { return 1 }; # Fehler!

   set curdir [pwd]
   cd $turdir
   cd $Tid


   # Bestimmen der Anzahl der Mannschaften und zu spielenden Runden
   set MAnzahl [array size mannschaften]
   set TlnAnzahl $MAnzahl
   if { ($TlnAnzahl & 1 ) == 1 } {
      incr TlnAnzahl
   }

   # Ausgabe der zu spielenden Runden
   for {set r 1} { $r < $TlnAnzahl} { incr r} {
      set s [db_runde_load $Tid $r wettkampf]

      if {$rundenerr} {set runden($r) " "}             
#      puts $fb "Runde $r : $runden($r)"
      foreach k [lsort -integer [array names wettkampf]] {
         set heim [lindex $wettkampf($k) 0]
         set gast [lindex $wettkampf($k) 1]
         if { [lindex $wettkampf($k) 2] == 1} then {
            set erg  [format "%-3s-%-3s  " [lindex $wettkampf($k) 3] [lindex $wettkampf($k) 5]] 
            set erg1 [format "%-3s-%-3s  " [lindex $wettkampf($k) 5] [lindex $wettkampf($k) 3]] 
         } elseif { [lindex $wettkampf($k) 2] == 2 } then {
            set erg  [format "%-3s-%-3skl" [lindex $wettkampf($k) 3] [lindex $wettkampf($k) 5]] 
            set erg1 [format "%-3s-%-3skl" [lindex $wettkampf($k) 5] [lindex $wettkampf($k) 3]] 
         } elseif { [lindex $wettkampf($k) 2] == 3 } then {
            set erg  [format "%-3s-%-3sme" [lindex $wettkampf($k) 3] [lindex $wettkampf($k) 5]] 
            set erg1 [format "%-3s-%-3sme" [lindex $wettkampf($k) 5] [lindex $wettkampf($k) 3]] 
         } else { set erg "___-___  "; set erg1 $erg } 
         set wettkaempfe($r,$heim,$gast) [list $r $k $heim $gast $wettkampf($k) $erg $erg1]
#        puts "$wettkaempfe($r,$heim,$gast)"
      }           
   }         

   return 0
}
