#===========================================================
#
# Procedure: cn_wettkampf_eingabe
#
# Purpose: Eingeben der Einzelergebnisse eines Wettkampfes
#
# Preconditions:
#  Wettkampf ist ausgewhlt, Parameter Runde und Tid sind richtig gesetzt.
#
# Postconditions:
#  Die Einzelergebnisse sind eingetragen und gespeichert, die
#  Mannschaftsergebnisse sind aktualisiert und im Window der
#  Wettkmpfe dargestellt.
#
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_wettkampf_eingabe { Tid Runde } {

   # Holen des ausgewhlten Wettkampfes
   set s [ui_wettkampf_getsel wettkampfnr]
   if {$s} {
      ui_warning "Auswahl" "Keine Runde ausgewhlt."
      return 1
   }

   # Darstellen des Wettkampfes selbst
   set s [ui_wettkampf_eingabe $Tid $Runde $wettkampfnr]

   return 0
}

#===========================================================
#
# Procedure: cn_wettkampf_kampflos
#
# Purpose: Eingeben kampfloser Wettkaempfe
#
# Preconditions:
#  Wettkampf ist ausgewhlt, Parameter Runde und Tid sind richtig gesetzt.
#
# Postconditions:
#  Fuer den ausgewaehlten Wettkampf wird entweder X:0, 0:X oder 0:0 
#  eingetragen. 
#  Mannschaftsergebnisse sind aktualisiert und im Window der
#  Wettkmpfe dargestellt.
#
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_wettkampf_kampflos { Tid Runde } {

   # Holen des ausgewhlten Wettkampfes
   set s [ui_wettkampf_getsel wettkampfnr]
   if {$s} {
      ui_warning "Auswahl" "Keine Runde ausgewhlt."
      return 1
   }

   # Darstellen des Wettkampfes selbst
   set s [ui_wettkampf_kampflos $Tid $Runde $wettkampfnr]

   return 0
}

#===========================================================
#
# Procedure: cn_wettkampf_store
#
# Purpose: Speichern eines Wettkampfergebnisses
#
# Preconditions:
#  Ergebnisse des Wettkampfes sind in Globals l_* gespeichert,
#  Turnier, Runde und Wettkampfnummer kommen als Parameter
#
# Postconditions:
#  Die Einzelergebnisse sind eingetragen und gespeichert, die
#  Mannschaftsergebnisse sind aktualisiert und im Window der
#  Wettkmpfe dargestellt.
#
# Globals
#  l_ergeb(*)
#  l_heim(*)
#  l_gast(*)
#
# Returns: 0 = success
#=============================================================
#
#  15-JUL-1996:   ni
#                 Pruefen, ob Anzahl Spieler korrekt
#=============================================================

proc cn_wettkampf_store { Tid Runde wettkampfnr heim gast } {
   #  Globals
   global l_ergeb
   global l_heim
   global l_gast

   # Holen der Spielnum
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]

   # Holen der gespielten Bretter
   set j 1
   for { set i 1 } { $i <= $Spielnum } { incr i } { set k_heim($i) 0 }
   foreach i [lsort -integer [array names l_heim]] {
      if {$l_heim($i) == "1" } {
         set k_heim($j) $i
         incr j
      }
   }

   # Prfen der Anzahl der angewhlten Heimspieler
   set j [expr $j-1]         
   if { $j != $Spielnum } { 
      ui_warning "Anzahl Spieler" "Die Anzahl der \
      angekreuzten Spieler der Heimmannschaft($j) ist ungleich $Spielnum - \
      Keine Speicherung durchgefhrt!"
      return 0
   }

   set j 1
   for { set i 1 } { $i <= $Spielnum } { incr i } { set k_gast($i) 0 }
   foreach i [lsort -integer [array names l_gast]] {
      if {$l_gast($i) == "1" } {
         set k_gast($j) $i
         incr j
      }
   }

   # Prfen der Anzahl der angewhlten Gastspieler
   set j [expr $j-1]         
   if { $j != $Spielnum } { 
      ui_warning "Anzahl Spieler" "Die Anzahl der \
      angekreuzten Spieler der Gastmannschaft($j) ist ungleich $Spielnum - \
      keine Speicherung durchgefhrt!"
      return 0
   }

   # Zusammenstellen der Brettergebnisse
   for { set i 1 } { $i <= $Spielnum } { incr i } {
      set Brettergebnisse($i) [list [list $heim $k_heim($i)] \
         [list $gast $k_gast($i)] $l_ergeb($i)]
   }   

   # Speichern 
   set s [db_wettkampf_store $Tid $Runde $wettkampfnr Brettergebnisse]
   if {$s} { return 1 }

   #  Aktualisieren der Rundenfiles
   set s [cn_runde_update $Tid $Runde $wettkampfnr Brettergebnisse]
   return 0
}

#===========================================================
#
# Procedure: cn_wettkampf_kl_store
#
# Purpose: Speichern eines kampflosen Wettkampfergebnisses
#
# Preconditions:
#  Ergebnisse des Wettkampfes sind in Globals l_* gespeichert,
#  Turnier, Runde und Wettkampfnummer kommen als Parameter
#
# Postconditions:
#  Die kampflosen Ergebnisse sind eingetragen und gespeichert, eventuelle
#  Einzelergebnisse geloescht.
#  Die Mannschaftsergebnisse sind aktualisiert und im Window der
#  Wettkmpfe dargestellt.
#
# Globals
#  l_kl_ergeb
#
# Returns: 0 = success
#=============================================================
#--------------------------------------------------------
# Changed:  6-MAY-1997, 27-MAY-1997
# Name: G.Niklaus
# Reason: Erweiterung auf kampflose Partien
#
#-------------------------------------------------------

proc cn_wettkampf_kl_store { Tid Runde wettkampfnr heim gast } {
   #  Globals
   global l_kl_ergeb

   # Holen der Spielnum
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
                           
   # Zusammenstellen des Mannschaftsergebnisses
   set m_ergeb $l_kl_ergeb

   # Speichern des kampflosen Wettkampfes
   set s [db_wettkampf_kl_store $Tid $Runde $wettkampfnr]
   if {$s} { return 1 }

   #  Aktualisieren der Rundenfiles fuer kampflosen Wettkampf
   set s [cn_runde_kl_update $Tid $Runde $wettkampfnr $m_ergeb]
   return 0
}

#===========================================================
#
# Procedure: cn_runde_update
#
# Purpose: Aktualisieren der Rundendateien
#
# Preconditions:
#  Wettkampf ist ausgewhlt, Parameter Runde und Tid sind richtig gesetzt.
#  Brettergebnisse sind ausgefllt.
#
# Postconditions:
#  Die Mannschaftsergebnisse sind aktualisiert und im Window der
#  Wettkmpfe dargestellt.
#
# Globals
#
# Returns: 0 = success
#          1 = failure
#=============================================================

proc cn_runde_update { Tid Runde wettkampfnr ArrayBrettergebnisse } {

   upvar $ArrayBrettergebnisse Brettergebnisse

   # Berechnung der Brett und Mannschaftspunkte
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   set siegpunkte $Spielleiter(Siegpunkte)
   set remispunkte 1

   set heimbrettpkt 0.0             
   set gastbrettpkt 0.0
   set heimmannpkt 0
   set gastmannpkt 0

   foreach i [array names Brettergebnisse] {
      set erg [lindex $Brettergebnisse($i) 2]
      switch -- $erg {
         {1-0} {set heimbrettpkt [expr $heimbrettpkt+1.0]}
         {0-1} {set gastbrettpkt [expr $gastbrettpkt+1.0]}
         {+/-} {set heimbrettpkt [expr $heimbrettpkt+1.0]}
         {-/+} {set gastbrettpkt [expr $gastbrettpkt+1.0]}
         {1/2} {set heimbrettpkt [expr $heimbrettpkt+0.5]; \
                set gastbrettpkt [expr $gastbrettpkt+0.5]}
      }
   }                                 

#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: 3-Punkte-Wertung
#
#-------------------------------------------------------
   if { $heimbrettpkt == [expr $Spielnum/2] } { set heimmannpkt $remispunkte }
   if { $gastbrettpkt == [expr $Spielnum/2] } { set gastmannpkt $remispunkte }
   if { $heimbrettpkt >  [expr $Spielnum/2] } { set heimmannpkt $siegpunkte }
   if { $gastbrettpkt >  [expr $Spielnum/2] } { set gastmannpkt $siegpunkte }

   # Holen des ausgewhlten Wettkampfes
   set s [db_runde_load $Tid $Runde wettkampf]

   set k1 [lindex $wettkampf($wettkampfnr) 0]
   set k2 [lindex $wettkampf($wettkampfnr) 1]

   set wettkampf($wettkampfnr) [list $k1 $k2 1 $heimbrettpkt $heimmannpkt \
        $gastbrettpkt $gastmannpkt]

   # Abspeichern
   set s [db_runde_speichern $Tid $Runde wettkampf]

   # Anzeige aktualisieren
   set s [db_mannschaft_selall $Tid mannschaft]
   set s [ui_runde_anzeige wettkampf mannschaft]

   return 0
}

#===========================================================
#
# Procedure: cn_runde_kl_update
#
# Purpose: Aktualisieren der Rundendateien fuer kampflosen Wettkampf
#
# Preconditions:
#  Wettkampf ist ausgewhlt, Parameter Runde und Tid sind richtig gesetzt.
#  Mannschaftsergebnis ist gefuellt.
#
# Postconditions:
#  Die Mannschaftsergebnisse sind aktualisiert und im Window der
#  Wettkmpfe dargestellt.
#
# Globals
#
# Returns: 0 = success
#          1 = failure
#=============================================================
#--------------------------------------------------------
# Changed: 27-MAY-1997
# Name: G.Niklaus
# Reason: Erweiterung auf kampflose Wettkaempfe
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: 
#         Eingabe von Wettkmpfen ohne Einzelergebnisse
#         
#         Wettkampfflag = 0 - Nicht gespielt
#                         1 - Gespielt, Einzelergebnisse
#                         2 - Kampflos
#                         3 - Gespielt, keine Einzelergebnisse
#-------------------------------------------------------

proc cn_runde_kl_update { Tid Runde wettkampfnr m_ergeb } {

   # Berechnung der Brett und Mannschaftspunkte
   set heimbrettpkt 0.0
   set gastbrettpkt 0.0

#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: 3-Punkte-Wertung
#
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  8-MAR-1999
# Name: G.Niklaus
# Reason: Bug fixing niederlagenpunkte -> niederlagepunkte
#
#-------------------------------------------------------
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   set siegpunkte $Spielleiter(Siegpunkte)
   set remispunkte 1            
   set niederlagepunkte 0
   set wettkampfflag 2
   set heimmannpkt $niederlagepunkte
   set gastmannpkt $niederlagepunkte

   if { $m_ergeb == "___ - ___" } { 
      set heimmannpkt $niederlagepunkte; 
      set gastmannpkt $niederlagepunkte;  
      set wettkampfflag 0
   } else {
      set heimpunkte [lindex $m_ergeb 0]
      set gastpunkte [lindex $m_ergeb 2]
      set x [lindex $m_ergeb 1]
      if { $x == "-" } {
         set wettkampfflag 3
      }

      set heimbrettpkt $heimpunkte
      set gastbrettpkt $gastpunkte
      set spielnum2 [expr $Spielnum/2]

      if { $heimpunkte > $spielnum2 } { 
         set heimmannpkt $siegpunkte
      } 
      if { $heimpunkte == $spielnum2 } {
         set heimmannpkt $remispunkte
      } 
      if { $heimpunkte < $spielnum2 } {
         set heimmannpkt $niederlagepunkte
      } 
      if { $gastpunkte > $spielnum2 } { 
         set gastmannpkt $siegpunkte
      } 
      if { $gastpunkte == $spielnum2 } {
         set gastmannpkt $remispunkte
      } 
      if { $gastpunkte < $spielnum2 } {
         set gastmannpkt $niederlagepunkte
      } 
   }

   # Holen des ausgewhlten Wettkampfes
   set s [db_runde_load $Tid $Runde wettkampf]

   set k1 [lindex $wettkampf($wettkampfnr) 0]
   set k2 [lindex $wettkampf($wettkampfnr) 1]


   set wettkampf($wettkampfnr) [list $k1 $k2 $wettkampfflag $heimbrettpkt $heimmannpkt \
        $gastbrettpkt $gastmannpkt]

   # Abspeichern
   set s [db_runde_speichern $Tid $Runde wettkampf]

   # Anzeige aktualisieren
   set s [db_mannschaft_selall $Tid mannschaft]
   set s [ui_runde_anzeige wettkampf mannschaft]

   return 0
}
#===========================================================
#
# Procedure: cn_tabelle
#
# Purpose: Erstellen der Tabelle
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde mu selektiert sein.
#  Bis zu dieser Runde wird die Tabelle gebildet.
#
# Postconditions:       
#  Tabelle ist erstellt wordem, in Datei gespeichert und in
#  Fenster angezeigt worden.
#
# Globals
#
# Returns: 0 = success
#=============================================================

proc cn_tabelle { } {

   # Holen und prfen, ob Turnier geffnet ist
   set s [db_Tid_get Tname Tid]
   if {$s} {
      ui_warning $Tname "Kein Turnier geffnet."
      return
   }

   # Prfen, ob schon ausgelost worden ist
   set s [db_auslos_get $Tid]
   if {$s} {
      ui_warning $Tname "Turnier ist nicht ausgelost, keine Tabelle mglich."
      return
   }

   # Holen der selektierten Runde  
   set s [ui_runde_getsel Runde Rundendatum]
   if {$s} {
      ui_warning $Tname "Keine Runde ausgewhlt."
      return
   }

   # Erstellen der Tabelle
   set s [cn_mannschaft_punkte $Tid $Runde Tabelle]
   if {$s} {
      ui_warning $Tname "Tabelle nicht erstellt"
      return
   }

   # Tabelle sortieren
   set s [cn_tabelle_sort Tabelle]

   # Tabelle speichern
   set s [db_tabelle_store $Tid Tabelle]

   # Tabelle anzeigen
   set s [ui_tabelle_display $Tname $Runde Tabelle]

   return 0
}

#===========================================================
#
# Procedure: cn_mannschaft_punkte
#
# Purpose: Ermitteln von Mannschafts- und Brettpunkten
#
# Preconditions:
#  Turnier ist ausgewhlt und ausgelost. Eine Runde ist angegeben.
#  Bis zu dieser Runde wird die Tabelle gebildet.
#
# Postconditions:       
#  Mannschafts- und Brettpunkte sind ermittelt.
#
# Ein Record der Tabelle:
#       Liste:  Nr {Mannschaft} s g u v {bpkt} {mpkt}
#
# Globals
#
# Returns: 0 = success
#=============================================================

#--------------------------------------------------------
# Changed: 14-FEB-1999
# Name: G.Niklaus
# Reason: 3-Punkte-Wertung
#
#-------------------------------------------------------
              
proc cn_mannschaft_punkte { Tid Runde ArrayTabelle } {

   upvar $ArrayTabelle Tabelle

   # Laden aller Mannschaften
   set s [db_mannschaft_selall $Tid mannschaft]
                         
   # Bilden der Tabellenstruktur
   foreach i [lsort -integer [array names mannschaft]] {
      set Tabelle($i) [list $i [lindex $mannschaft($i) 1] 0 0 0 0 0.0 0]
   }

   # Laden der Runden
   for { set i 1 } { $i <= $Runde } { incr i } {
      set s [db_runde_load $Tid $i wettkampf]
      foreach k [array names wettkampf] {
         set heim [lindex $wettkampf($k) 0]
         set gast [lindex $wettkampf($k) 1]    
         set flag [lindex $wettkampf($k) 2]
         set hbp  [lindex $wettkampf($k) 3]
         set hmp  [lindex $wettkampf($k) 4]
         set gbp  [lindex $wettkampf($k) 5]
         set gmp  [lindex $wettkampf($k) 6]
         if {$flag} {
            set hname [lindex $Tabelle($heim) 1]
            set hs    [lindex $Tabelle($heim) 2]
            set hg    [lindex $Tabelle($heim) 3]
            set hu    [lindex $Tabelle($heim) 4]
            set hv    [lindex $Tabelle($heim) 5]
            set hbpkt [lindex $Tabelle($heim) 6]
            set hmpkt [lindex $Tabelle($heim) 7]
            set gname [lindex $Tabelle($gast) 1]
            set gs    [lindex $Tabelle($gast) 2]
            set gg    [lindex $Tabelle($gast) 3]
            set gu    [lindex $Tabelle($gast) 4]
            set gv    [lindex $Tabelle($gast) 5]
            set gbpkt [lindex $Tabelle($gast) 6]
            set gmpkt [lindex $Tabelle($gast) 7]

            incr hs
            set hmpkt [expr $hmpkt+$hmp]
            set hbpkt [expr $hbpkt+$hbp]
            switch -- $hmp {
               0 {  incr hv }
               1 {  incr hu }
               2 {  incr hg }
               3 {  incr hg }
            }
            incr gs
            set gmpkt [expr $gmpkt+$gmp]
            set gbpkt [expr $gbpkt+$gbp]
            switch -- $gmp {
               0 {  incr gv }               
               1 {  incr gu }
               2 {  incr gg }
               3 {  incr gg }
            }
            set Tabelle($heim) [list $heim $hname $hs $hg $hu $hv $hbpkt $hmpkt]
            set Tabelle($gast) [list $gast $gname $gs $gg $gu $gv $gbpkt $gmpkt]
         }
      }
   }
   return 0
}


