#============================================================
#
# Procedure: db_runde_speichern
#
# Purpose: Speichern der Wettkmpfe einer Runde
#
# Preconditions: Turnier mu geffnet sein.
#   Auslosung mu durchgefhrt sein. Tid und Runde mssen einen
#   gltigen Wert besitzen, wettkampf mssen gefllt sein
# 
# Postconditions:
#  Alle Wettkmpfe der Runde sind gespeichert
#
# Globals:
#   turdir
#   wettkampffile
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Bercksichtigung Directory
#
#-------------------------------------------------------
proc db_runde_speichern { Tid Runde Arraywettkampf } {
   # Globals
   global turdir
   global wettkampffile

   upvar $Arraywettkampf wettkampf

   set curdir [pwd]
   cd $turdir/$Tid

   set i 0
   set fa [open $wettkampffile.$Runde w]  
   foreach i [lsort -integer [array names wettkampf]] {
      puts $fa $wettkampf($i)
   }
   close $fa
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_spielplan_selall
#
# Purpose: Laden des Spielplanes
#
# Preconditions: Turnier mu geffnet sein.
#   Auslosung mu durchgefhrt sein. Tid mu
# 
# Postconditions:
#  Spielplan ist geladen und wird zurckgegeben.
#
# Globals:
#   turdir
#   wettkampffile
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_spielplan_selall { Tid Varspielplan } {
   # Globals
   global turdir
   global spielplanfile

   upvar $Varspielplan spielplan

   set curdir [pwd]
   cd $turdir
   cd $Tid
                    
   if { [file exists $spielplanfile] == 1 } {
      set f1 [open $spielplanfile r]
      set spielplan [read -nonewline $f1]
      close $f1
      return 0
   } else {
      return 1
   }   
}

#============================================================
#
# Procedure: db_wettkampf_load
#
# Purpose: Laden eines Wettkampfes
#
# Preconditions: Die Nummer des Wettkampfes sowie Tid und Runde
#  mssen korrekt sein.
# 
# Postconditions:
#  Gewnschter Wettkampf ist geladen.
#
# Globals:
#   turdir
#   mannschaftsergebnisfile
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_wettkampf_load { Tid Runde wettkampfnr ArrayBrettergebnisse } {
   # Globals
   global turdir
   global mannschaftsergebnisfile

   upvar $ArrayBrettergebnisse Brettergebnisse

   set curdir [pwd]
   cd $turdir
   cd $Tid
                    
   if { [file exists $mannschaftsergebnisfile$Runde.$wettkampfnr] == 1 } {
      set f1 [open $mannschaftsergebnisfile$Runde.$wettkampfnr r]
      set j 0
      gets $f1 zeile
      while {![eof $f1]} {
         incr j
         set Brettergebnisse($j) $zeile
         gets $f1 zeile
      }
      close $f1
      cd $curdir
      return 0
   } else {
      cd $curdir
      return 1
   }   
}

#============================================================
#
# Procedure: db_wettkampf_store
#
# Purpose: Speichern eines Wettkampfes
#
# Preconditions: Die Nummer des Wettkampfes sowie Tid und Runde
#  mssen korrekt sein. Die Brettergebnisse sind gefllt.
# 
# Postconditions:
#  Wettkampf ist gespeichert.
#
# Globals:
#   turdir
#   mannschaftsergebnisfile
#              
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_wettkampf_store { Tid Runde wettkampfnr ArrayBrettergebnisse } {
   # Globals
   global turdir
   global mannschaftsergebnisfile

   upvar $ArrayBrettergebnisse Brettergebnisse

   set curdir [pwd]
   cd $turdir
   cd $Tid
                    
   set f1 [open $mannschaftsergebnisfile$Runde.$wettkampfnr w]
   foreach i [lsort -integer [array names Brettergebnisse]] {
      puts $f1 $Brettergebnisse($i)
   }
   close $f1
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_spieler_load
#
# Purpose: Laden der Spieler einer Mannschaft
#
# Preconditions: 
#  Tid zeigt auf geffnetes Turnier
#  Mid enthlt die ID der Mannschaft, deren Spieler zu laden sind.
# 
# Postconditions:
#  Die Spieler der Mannschaft sind geladen.
#
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_spieler_load { Tid Mid ArraySpieler } {
              
   upvar $ArraySpieler Spieler

   set s [db_meldung_load $Tid $Mid Meldung] 
   if {$s} { return 1 }
  
   # Wegwerfen der Kommentarzeichen
   foreach i [lsort -integer [array names Meldung]] {
      set zeile [string trim $Meldung($i)]
      if { [string index $zeile 0] != "#" } {
         set zeile [string range $zeile 0 36]; # oder 45
         set brett [string trim [string range $zeile 0 2]]
         set hilf [string length $zeile]
         if { [string length $zeile] > 0 } {
            set zeil ""
            foreach k $zeile {lappend zeil $k}
            set Spieler($brett) $zeil
         }
      }
   }
   return 0
}

#============================================================
#
# Procedure: db_meldung_load
#
# Purpose: Laden einer Mannschaftsmeldung
#
# Preconditions:
#  Die Mannschaft Mid aus dem Turnier Tid wird geladen.
# 
# Postconditions:
#  Mannschaftsmeldung ist geladen
#
# Globals:
#   turdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_meldung_load { Tid Mid ArrayMeldung } {
   # Globals
   global turdir

   upvar $ArrayMeldung Meldung

   set curdir [pwd]
   cd $turdir                             
   cd $Tid
                    
   if { [file exists $Mid] == 1 } {
      set f1 [open $Mid r]
      set j 0
      gets $f1 zeile
      while {![eof $f1]} {
         incr j
         set Meldung($j) $zeile
         gets $f1 zeile
      }
      close $f1
      cd $curdir         
      return 0
   } else {
      cd $curdir
      return 1
   }   
}

#============================================================
#
# Procedure: db_tabelle_store
#
# Purpose: Speichern der Tabelle
#
# Preconditions:
#  Tid mu gltigen Wert haben, Tabelle mu gefllt sein.
# 
# Postconditions:
#  Tabelle ist gespeichert
#
# Globals:
#   turdir
#   tabellenfile
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_tabelle_store { Tid ArrayTabelle } {
   # Globals
   global turdir
   global tabellenfile

   upvar $ArrayTabelle Tabelle

   set curdir [pwd]
   cd $turdir
   cd $Tid
                      
   set f1 [open $tabellenfile w]
   puts $f1 "Tabellenstand                   S   G   U   V    Bpkt  Mpkt"
   puts $f1 "-----------------------------------------------------------"
   foreach k [lsort -integer [array names Tabelle]] {
      set temp [format "%4s : %-22s %3s %3s %3s %3s   %5s   %3s" $k \
          [lindex $Tabelle($k) 1] \
          [lindex $Tabelle($k) 2] \
          [lindex $Tabelle($k) 3] \
          [lindex $Tabelle($k) 4] \
          [lindex $Tabelle($k) 5] \
          [lindex $Tabelle($k) 6] \
          [lindex $Tabelle($k) 7] ]
      puts $f1 $temp
   }
   puts $f1 ""
   close $f1
   cd $curdir         
   return 0
}

#============================================================
#
# Procedure: db_rangliste_store
#
# Purpose: Speichern der Rangliste
#
# Preconditions:
#  Tid mu gltigen Wert haben, Rangliste mu gefllt sein.
# 
# Postconditions:
#  Rangliste ist gespeichert
# 
# Globals:
#   turdir
#   toptenfile
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
proc db_rangliste_store { Tid Num ArrayRangliste } {
   # Globals
   global turdir
   global toptenfile

   upvar $ArrayRangliste Rangliste

   set curdir [pwd]
   cd $turdir
   cd $Tid
                      
   set max [array size Rangliste]
   if { $Num < $max } { set max $Num }
   
   set f1 [open $toptenfile w]
   puts $f1 "Rangliste Einzelspieler       Mannschaft            Brett  Punkte  Spiele"
   puts $f1 "-------------------------------------------------------------------------"
   for { set k 1 } { $k <= $max } { incr k } {
      set temp [format "%4s : %-22s %-22s  %3s  %5s %6s" $k \
          [lindex $Rangliste($k) 1] \
          [lindex $Rangliste($k) 2] \
          [lindex $Rangliste($k) 0] \
          [lindex $Rangliste($k) 3] \
          [lindex $Rangliste($k) 4] ]
      puts $f1 $temp
   }
   puts $f1 ""
   close $f1
   cd $curdir         
   return 0
}


