#============================================================
#
# Procedure: db_releasenotes_selall
#              
# Purpose: Laden der Releasenotes aus Datei
#
# Preconditions:
#  Parameter filename muss auf Datei der Releasenotes zeigen
# 
# Postconditions:
#  Releasenotes sind in Variable "Releasenotes" geladen
# 
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_releasenotes_selall { relnotesfile VarReleasenotes } {
   upvar $VarReleasenotes Releasenotes

   set f1 [open $relnotesfile r]
   set Releasenotes [read -nonewline $f1]
   close $f1
   return 0
}

#============================================================
#
# Procedure: db_usersguide_selall
#              
# Purpose: Laden des Users Guide aus Datei
#
# Preconditions:
#  Parameter filename muss auf Datei des User Guide zeigen
# 
# Postconditions:
#  User Guide ist in Variable "Guide" geladen
# 
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_usersguide_selall { usersguide VarGuide } {
   upvar $VarGuide Guide 

   set f1 [open $usersguide r]
   set Guide [read -nonewline $f1]
   close $f1
   return 0
}

#============================================================
#
# Procedure: db_wettkampf_kl_store
#              
# Purpose: Speichern eines kampflosen Wettkampfes
#
# Preconditions:
#  Parameter Tid, Runde und wettkampfnr zeigen auf den Wettkampf,
#  der kampflos ausging.
# 
# Postconditions:
#  Die Datei, in der eventuelle Brettergebnisse gespeichert waren,
#  ist geloescht.
# 
# Globals:
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed: 27-MAY-1997
# Name: G.Niklaus
# Reason: Erweiterung auf kampflose Wettkaempfe
#
#-------------------------------------------------------

proc db_wettkampf_kl_store { Tid Runde wettkampfnr } {
   global turdir
   global remofilcmd
   global mannschaftsergebnisfile

   set curdir [pwd]
   cd $turdir/$Tid

   set remofil [format $remofilcmd $mannschaftsergebnisfile$Runde.$wettkampfnr]
   catch {eval $remofil}

   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_spielplan_anhang_selall
#              
# Purpose: Laden des Spielplan-Anhanges aus Datei
#
# Preconditions:
#  Turnier mu geffnet sein
#  Anhang-Datei mu nicht unbedingt vorhanden sein.
# 
# Postconditions:
#  Anhang-Datei ist geladen
#  Name der Anhangsdatei ist in Variable Dateiname
# 
# Globals:
# turdir
# spielplananhang
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_spielplan_anhang_selall { Tid VarSpielplan_Anhang VarDateiname } {
   global turdir
   global spielplananhang

   upvar $VarSpielplan_Anhang Spielplan_Anhang 
   upvar $VarDateiname Dateiname

   set Spielplan_Anhang "";
   set Dateiname $turdir/$Tid/$spielplananhang
   if { [file exists $Dateiname] == 1 } {
      set f1 [open $Dateiname r]
      set Spielplan_Anhang [read -nonewline $f1]
      close $f1
   }
   return 0
}

#============================================================
#
# Procedure: db_spielplan_anhang_store
#              
# Purpose: Speichern der Spielplan-Anhanges in Datei
#
# Preconditions:
#  Turnier mu geffnet sein
#  Anhang-Datei mu nicht unbedingt vorhanden sein.
# 
# Postconditions:
#  Anhang-Datei ist gespeichert 
# 
# Globals:          
# turdir
# spielplananhang
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_spielplan_anhang_store { Tid } {
   global turdir
   global spielplananhang

   set w .ui_spielplan_anhang_enter

   set Dateiname $turdir/$Tid/$spielplananhang
   set anhang [$w.text get 0.0 end]
   set f1 [open $Dateiname w]
   puts -nonewline $f1 $anhang
   close $f1
   return 0
}

#============================================================
#
# Procedure: db_rundenbericht_anhang_selall
#              
# Purpose: Laden des Rundenberich-Anhanges aus Datei
#
# Preconditions:
#  Turnier mu geffnet sein
#  Runde mu angegeben sein
#  Anhang-Datei mu nicht unbedingt vorhanden sein.
# 
# Postconditions:
#  Anhang-Datei ist geladen
#  Name der Anhangsdatei ist in Variable Dateiname
# 
# Globals:
# turdir
# rundenanhang
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_rundenbericht_anhang_selall { Tid Runde VarRunden_Anhang VarDateiname } {
   global turdir
   global rundenanhang

   upvar $VarRunden_Anhang Runden_Anhang 
   upvar $VarDateiname Dateiname

   set Runden_Anhang "";
   set Dateiname $turdir/$Tid/$rundenanhang$Runde
   if { [file exists $Dateiname] == 1 } {
      set f1 [open $Dateiname r]
      set Runden_Anhang [read -nonewline $f1]
      close $f1
   }
   return 0
}

#============================================================
#
# Procedure: db_rundenbericht_anhang_store
#              
# Purpose: Speichern des Runden-Anhanges in Datei
#
# Preconditions:
#  Turnier mu geffnet sein
#  Runde mu angegeben sein.
#  Anhang-Datei mu nicht unbedingt vorhanden sein.
# 
# Postconditions:
#  Anhang-Datei ist gespeichert 
# 
# Globals:
# turdir
# rundenanhang
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_rundenbericht_anhang_store { Tid Runde } {
   global turdir
   global rundenanhang

   set w .ui_rundenbericht_anhang_enter

   set Dateiname $turdir/$Tid/$rundenanhang$Runde
   set f1 [open $Dateiname w]
   set anhang [$w.text get 0.0 end]
   puts -nonewline $f1 $anhang
   close $f1
   return 0
}

#============================================================
#
# Procedure: db_turnier_export
#              
# Purpose: Exportieren eines Turnieres in eine ZIP-Datei
#
# Preconditions:
#  Kein Turnier darf geffnet sein
#  Das zu exportierende Turnier wird im Parameter bergeben.
#  ZIP-Datei mu nicht unbedingt vorhanden sein.
# 
# Postconditions:
#  Turnier ist exportiert worden.
#                    
# Globals:
# turdir
# exportdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_turnier_export { Tid } {
   global turdir
   global exportcmd
   global G_exportdatei

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set export [format $exportcmd $G_exportdatei]
   catch { eval "exec $export" }
   cd $curdir
   return 0
}

#============================================================
#
# Procedure: db_turnier_import
#              
# Purpose: Importieren eines Turnieres aus einer ZIP-Datei
#
# Preconditions:
#  Kein Turnier darf geffnet sein
#  Das zu importierende Turnier wird im Parameter bergeben.
#  ZIP-Datei mu vorhanden sein.
# 
# Postconditions:
#  Turnier ist importiert worden, das urspruenglich vorhandene
#  Turnier wurde ueberschrieben
#                    
# Globals:
# turdir
# exportdir
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc db_turnier_import { Tid } {
   global turdir
   global importcmd
   global G_exportdatei

   set curdir [pwd]
   cd $turdir
   cd $Tid

   set import [format $importcmd $G_exportdatei]
   catch { eval "exec $import" }
   cd $curdir
   return 0
}
