#============================================================
#
# Procedure: ui_runde_enter
#
# Purpose: Eingabe des Datums einer Runde.
#
# Preconditions: 
#  Turnier mu geffnet sein. Runde kann, mu aber nicht unbedingt
#  ein Datum haben. Abhngig vom Schalter func wird entweder ein 
#  modify oder ein add gemacht.
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Die erhaltenen Werte werden im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#     G_Runde        - zu ndernde Runde
#     G_Rundendatum  - zu nderndes Rundendatum
#
# Returns: Keine
#
#=============================================================

proc ui_runde_enter { Runde Rundendatum func } {
# Verwendete globale Variable
global G_Runde  
global G_Rundendatum

   if { [string compare $func "modify"] == 0 } {
      set Titel "Runde ndern"
      set Text "Bitte fr Runde $Runde den neuen Termin angeben und mit OK abschlieen."
      set G_Runde $Runde
      set G_Rundendatum $Rundendatum
   } else {
      set Titel "Neue Runde"
      set Text "Bitte fr die neue Runde den Termin angeben und mit OK abschlieen."
      set G_Runde ""
      set G_Rundendatum ""           
   }                                                                  

   # Aufbau des UIs
   set w .ui_runde_enter
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
   
   message $w.msg -text $Text  -aspect 500
              
   frame $w.frame -bd 3
   pack $w.msg -side top
   pack $w.frame -side top -expand yes -fill y
               
   button $w.ok -text OK -command "[list cn_runde_save $func]; destroy $w"
   button $w.cancel -text Abbrechen -command "destroy $w"
   
   frame $w.frame.datum
   label $w.frame.datum.text -text {Spieltermin:}
   entry $w.frame.datum.val  -relief sunken -width 20 -textvariable G_Rundendatum
   
   pack $w.frame.datum -side top
   pack $w.frame.datum.text -side top -anchor w
   pack $w.frame.datum.val -side top -anchor w
   pack $w.ok -side left -fill x -expand yes
   pack $w.cancel -side right -fill x -expand yes
}

#============================================================
#
# Procedure: ui_mannschaft_exchange
#
# Purpose: Vertauschen zweier Mannschaften
#
# Preconditions: 
#  Turnier mu geffnet sein. 
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Die erhaltenen Werte werden im UI dargestellt.
#  Das UI ist ein separates Window. Die Startnummern der beiden Mannschaften
#  werden abgefragt und in den globalen Variablen G_Nr1 ud G_Nr2 gespeichert.
#
# Globals:
#     G_Nr1
#     G_Nr2
#
# Returns: Keine
#
#=============================================================
proc ui_mannschaft_exchange { } {
   # Verwendete globale Variable
   global G_Nr1
   global G_Nr2

   set Titel "Startnummern tauschen"
   set Text "Bitte die Nummern der beiden Mannschaften, die getauscht \
   werden sollen, angeben und mit OK abschlieen."

   # Aufbau des UIs
   set w .ui_mannschaft_exchange
   set G_Nr1 ""
   set G_Nr2 ""
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
   
   message $w.msg -text $Text  -aspect 500
              
   frame $w.frame -bd 3
   pack $w.msg -side top
   pack $w.frame -side top -expand yes -fill y
               
   button $w.ok -text OK -command "cn_mannschaft_tauschen; destroy $w"
   button $w.cancel -text Abbrechen -command "destroy $w"
                                      

   frame $w.frame.ms         
   label $w.frame.ms.text -text {Mannschaft Nummer :}
   entry $w.frame.ms.val  -relief sunken -width 5 \
       -textvariable G_Nr1

   pack $w.frame.ms -side top -fill x -expand yes
   pack $w.frame.ms.text -side left -fill x -expand true -anchor w
   pack $w.frame.ms.val -side right -anchor e

   frame $w.frame.hs
   label $w.frame.hs.text -text {Vertauschen mit:}
   entry $w.frame.hs.val  -relief sunken -width 5 \
         -textvariable G_Nr2

   pack $w.frame.hs -side top -fill x -expand yes
   pack $w.frame.hs.text -side left -fill x -expand true -anchor w
   pack $w.frame.hs.val -side right -anchor e

   pack $w.ok -side left -fill x -expand yes
   pack $w.cancel -side right -fill x -expand yes

   # Lokaler Grab, wird aufgehoben durch Zerstren des Windows
   update idletask
   grab $w
   tkwait window $w
   return 0
}

#============================================================
#
# Procedure: ui_warning
#
# Purpose: Ausgabe einer Warnung in ein Popup Window
#
# Preconditions: 
#  Titel und Text der Meldung werden bergeben.
#
# Postconditions:
#  Window ist wieder gelscht.
#
# Globals: keine
#
# Returns: Keine
#
#=============================================================

proc ui_warning { Titel Text } {
   AlertBox "$Text" return {200x50} "$Titel" ok
   return
}

#============================================================
#
# Procedure: ui_turnier_display
#
# Purpose: Steuern der Anzeige der Turnierdaten
#
# Preconditions: 
#  Turnier mit Tid mu geffnet sein.
#  Werte Tname, Spielnum,... mssen gefllt sein.
#
# Postconditions:
#  Hauptwindow ist aktulasiert
#
# Globals: Hauptwindow-Widgets
#
# Returns: 0 = success
#
#=============================================================


proc ui_turnier_display { Tid Tname Spielnum ArraySpielleiter Arrayrunden 
                          Arraymannschaften } {

   upvar $ArraySpielleiter Spielleiter
   upvar $Arrayrunden runden
   upvar $Arraymannschaften mannschaften

   set s [ui_runde_display runden]
   set s [ui_mannschaft_display mannschaften]
   set s [ui_turnierdat_display $Tid $Tname $Spielnum Spielleiter]
   return 0
                                             
}
                          
#============================================================
#
# Procedure: ui_runde_display
#
# Purpose: Ausgabe der vorhandenen Runden des Turnieres
#
# Preconditions: 
#   Turnier geffnet. Array runden enthlt die Spieltermine.
#
# Postconditions:
#  Inhalt des Arrays runden ist in Hauptwindow in 
#     .mannschaftundrunden.runden.runden
#     .mannschaftundrunden.mannschaft.mannschaft 
#
# Globals: keine
#
# Returns: 0 = success
#
#=============================================================

proc ui_runde_display { Arrayrunden } {
   upvar $Arrayrunden runden

   if { [info exists runden] == 1 } {
      set r .mannschaftundrunden.runden.runden
      $r delete 0 end

      foreach i [lsort -integer [array names runden]] {
         set temp [format "%4s %20s" $i $runden($i)]
         $r insert end $temp
      }
   }                   
}

#============================================================
#
# Procedure: ui_mannschaft_display
#
# Purpose: Ausgabe der vorhandenen Mannschaften des Turnieres
#
# Preconditions: 
#   Turnier geffnet. Array mannschaft enthlt die Mannschaften.
#
# Postconditions:
#  Inhalt des Arrays mannschaft ist in Hauptwindow in 
#     .mannschaftundrunden.mannschaft.mannschaft 
#
# Globals: keine
#
# Returns: 0 = success
#
#=============================================================

proc ui_mannschaft_display { Arraymannschaften } {
   upvar $Arraymannschaften mannschaften

   if { [info exists mannschaften] == 1 } {
      set r .mannschaftundrunden.mannschaft.mannschaft
      $r delete 0 end
      foreach i [lsort -integer [array names mannschaften]] {
         set temp [format "%4s : %-20s: %-20s" $i [lindex $mannschaften($i) 1] [lindex $mannschaften($i) 2]]
         $r insert end $temp
      }     
   }                                        
}

#============================================================
#
# Procedure: ui_mannschaft_enter
#
# Purpose: Eingabe der Daten einer Mannschaft
#
# Preconditions: 
#  Turnier mu geffnet sein. Nr kann, mu aber nicht unbedingt
#  ein Datum haben. Abhngig vom Schalter func wird entweder ein 
#  modify oder ein add gemacht.
#
# Postconditions:
#  Das User Interface wird aufgebaut, u.U schon vorher vorhandenes UI
#  wird gelscht. Die erhaltenen Werte werden im UI dargestellt.
#  Das UI ist ein separates Window.
#
# Globals:
#     G_Nr           - Nummer der zu ndernden Mannschaft
#     G_Mid          - Mannschaftsid
#     G_Name         - Name der Mannschaft
#     G_Heimspieltag - Heimspieltag der Mannschaft
#
# Returns: Keine
#
#=============================================================

proc ui_mannschaft_enter { Nr Mid Name Heimspieltag func } {
   # Verwendete globale Variable
   global G_Nr
   global G_Mid
   global G_Name
   global G_Heimspieltag

   if { [string compare $func "modify"] == 0 } {
      set Titel "Mannschaft ndern"
      set Text "Bitte fr Mannschaft $Nr den neuen Namen und Heimspieltag angeben und mit OK abschlieen."
      set G_Nr $Nr
      set G_Mid $Mid
      set G_Name $Name
      set G_Heimspieltag $Heimspieltag
   } else {
      set Titel "Neue Mannschaft"
      set Text "Bitte fr die neue Mannschaft den Namen und den Heimspieltag angeben und mit OK abschlieen."
      set G_Nr ""
      set G_Mid $Mid
      set G_Name ""
      set G_Heimspieltag ""
   }

   # Aufbau des UIs
   set w .ui_mannschaft_enter
   catch {destroy $w}
   toplevel $w
   wm title $w "$Titel"
   wm minsize $w 1 1
   
   message $w.msg -text $Text  -aspect 500
              
   frame $w.frame -bd 3
   pack $w.msg -side top
   pack $w.frame -side top -expand yes -fill y
               
   button $w.ok -text OK -command "[list cn_mannschaft_save $func]; destroy $w"
   button $w.cancel -text Abbrechen -command "destroy $w"
   
   frame $w.frame.name 
   label $w.frame.name.text -text {Name der Mannschaft:}
   entry $w.frame.name.val  -relief sunken -width 30 -textvariable G_Name 
   frame $w.frame.heimspieltag
   label $w.frame.heimspieltag.text -text {Heimspieltag:}
   entry $w.frame.heimspieltag.val  -relief sunken -width 20 -textvariable G_Heimspieltag
   
   pack $w.frame.name -side top
   pack $w.frame.name.text -side top -anchor w
   pack $w.frame.name.val -side top -anchor w
   pack $w.frame.heimspieltag -side top
   pack $w.frame.heimspieltag.text -side top -anchor w
   pack $w.frame.heimspieltag.val -side top -anchor w
   pack $w.ok -side left -fill x -expand yes
   pack $w.cancel -side right -fill x -expand yes
}
