#============================================================
#
# Procedure: ui_runde_anzeige
#
# Purpose: Darstellen der Wettkmpfe einer Runde im Window
#  
# Preconditions: 
#  Parameter "wettkampf" und "mannschaft" sind gefllt.
#
# Postconditions:
#  Wettkmpfe sind mit Namen und Ergebnisse dargestellt.
#
# Globals: 
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed: 27-MAY-1997
# Name: G.Niklaus
# Reason: Anzeige kampfloser Wettkaempfe
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Anzeige von Wettkmpfen ohne Brettergebnisse "me"
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  7-Jul-1998
# Name: G.Niklaus
# Reason: Fehlerbehandlung zum aktukalisieren der Ergebnisse in Widgets
#-------------------------------------------------------

proc ui_runde_anzeige { Arraywettkampf Arraymannschaft } {

   upvar $Arraywettkampf wettkampf
   upvar $Arraymannschaft mannschaft

   set w .runde_eingabe

      catch {$w.frame.list delete 0 end}
#   $w.frame.list delete 0 end

   foreach k [lsort -integer [array names wettkampf]] {
      set heim [lindex $wettkampf($k) 0]
      set gast [lindex $wettkampf($k) 1]
      switch -- [lindex $wettkampf($k) 2] {
         0 { set erg "___ - ___    " }
         1 { set erg "[lindex $wettkampf($k) 3] - [lindex $wettkampf($k) 5]    " }
         2 { set erg "[lindex $wettkampf($k) 3] - [lindex $wettkampf($k) 5] kl " }
         3 { set erg "[lindex $wettkampf($k) 3] - [lindex $wettkampf($k) 5] me " }
      }
      set temp [format "%3s : %-22s %13s %-22s" $k \
            [lindex $mannschaft($heim) 1] $erg [lindex $mannschaft($gast) 1]]
      catch {$w.frame.list insert end $temp}
      if {[winfo exists .kreuztabelle] ==1 } {cn_kreuztabelle_display}
   }
   return 0
}

#============================================================
#
# Procedure: ui_wettkampf_kampflos
#
# Purpose: Eingabe eines kampflosen Wettkampfes
#
# Preconditions: 
#  Parameter "Tid", "Runde" und "wettkampfnr" sind gefllt.
#
# Postconditions:
#  Die beiden Mannschaften und die kampflos moeglichen Ergebnisse sind
#  dargestellt
#
# Globals: 
#  l_kl_ergeb     : X-0, 0-X, _:_
# (  l_kl_spielflag : 0,1,2 )
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed:  6-MAY-1997
# Name: G.Niklaus
# Reason: Creation
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Erweiterung auf reine Mannschaftsergebnisse
#-------------------------------------------------------

proc ui_wettkampf_kampflos { Tid Runde wettkampfnr } {
   #  Globals
   global l_kl_ergeb

   set v .wettkampf_kampflos
   catch {destroy $v}
   toplevel $v
   wm title $v "Eingabe eines Mannschaftsergebnisses"

   set w $v.w
                                          
   set s [db_mannschaft_selall $Tid mannschaft]
   set s [db_runde_load $Tid $Runde wettkampf]

   set heim [lindex $wettkampf($wettkampfnr) 0]
   set gast [lindex $wettkampf($wettkampfnr) 1]

   set l_kl_ergeb "___ - ___"

   frame $w
   frame $w.e
   frame $w.buttons
   message $w.msg -width 500 \
         -text "Bitte Mannschaftsergebnis eingeben. \
                Standard: \"Punkte - Punkte\", \
                Kampflos: \"Punkte : Punkte\" "
   pack $w -side top
   pack $w.msg -side top
   pack $w.e -side top
   pack $w.buttons -side top -expand yes -fill x
   button $w.buttons.ok -text Speichern \
      -command "cn_wettkampf_kl_store $Tid $Runde $wettkampfnr $heim $gast"
   button $w.buttons.cancel -text Beenden -command "destroy $v"
   pack $w.buttons.ok     -side left -expand yes -fill x
   pack $w.buttons.cancel -side right -expand yes -fill x
  
   frame $w.e.heim  -bd 3 -relief raised
   frame $w.e.erg   -bd 3 -relief raised
   frame $w.e.gast  -bd 3 -relief raised                   
   pack  $w.e.heim  -side left -anchor n
   pack  $w.e.erg   -side left -anchor n
   pack  $w.e.gast  -side left -anchor n
                 
   message $w.e.heim.msg -width 500 -text [lindex $mannschaft($heim) 1]
#   message $w.e.erg.msg  -width 500 -text "Ergebnis"
   message $w.e.gast.msg -width 500 -text [lindex $mannschaft($gast) 1]

   pack $w.e.heim.msg -side top -fill x
#   pack $w.e.erg.msg -side top -fill x
   pack $w.e.gast.msg -side top -fill x

   # Darstellen Bretter
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
#   for {set i 1} { $i <= $Spielnum} { incr i } {
      entry $w.e.erg.ergebnis -relief sunken -width 9 -textvariable l_kl_ergeb
      pack $w.e.erg.ergebnis -side left
      bind $w.e.erg.ergebnis <Double-Button-1> "ui_kampflos_set $v $Spielnum"
#   }
                  
   return 0
}               

#============================================================
#
# Procedure: ui_wettkampf_eingabe
#
# Purpose: Eingabe der Einzelergebnisse eines Wettkampfes
#
# Preconditions:                                               
#  Parameter "Tid", "Runde" und "wettkampfnr" sind gefllt.
#
# Postconditions:
#  Alle Spieler der Mannschaften und die Einzelergebnisse sind dargestellt.
#
# Globals: 
#  l_ergeb(*)
#  l_heim(*)
#  l_gast(*)
#
# Returns: 0 = success
#          1 = Fehler
#=============================================================

proc ui_wettkampf_eingabe { Tid Runde wettkampfnr } {
   #  Globals
   global l_ergeb
   global l_heim
   global l_gast           

   set v .wettkampf_eingabe
   catch {destroy $v}
   toplevel $v
   wm title $v "Einzelergebnisse"

   set w $v.w
                                          
   set s [db_mannschaft_selall $Tid mannschaft]
   set s [db_runde_load $Tid $Runde wettkampf]

   set heim [lindex $wettkampf($wettkampfnr) 0]
   set gast [lindex $wettkampf($wettkampfnr) 1]

   set Mid [lindex $mannschaft($heim) 0]
   set s [db_spieler_load $Tid $Mid Heimspieler]

   set Mid [lindex $mannschaft($gast) 0]
   set s [db_spieler_load $Tid $Mid Gastspieler]
       
   frame $w
   frame $w.e
   frame $w.buttons
   message $w.msg -width 500 \
         -text "Bitte Spieler und Ergebnisse anwhlen."
   pack $w -side top
   pack $w.msg -side top
   pack $w.e -side top
   pack $w.buttons -side top -expand yes -fill x
   button $w.buttons.ok -text Speichern \
      -command "cn_wettkampf_store $Tid $Runde $wettkampfnr $heim $gast"
   button $w.buttons.cancel -text Beenden -command "destroy $v"
   pack $w.buttons.ok     -side left -expand yes -fill x
   pack $w.buttons.cancel -side right -expand yes -fill x
  
   frame $w.e.heim  -bd 3 -relief raised
   frame $w.e.erg   -bd 3 -relief raised
   frame $w.e.gast  -bd 3 -relief raised
   pack  $w.e.heim  -side left -anchor n
   pack  $w.e.erg   -side left -anchor n
   pack  $w.e.gast  -side left -anchor n

   message $w.e.heim.msg -width 500 -text [lindex $mannschaft($heim) 1]
   message $w.e.erg.msg  -width 500 -text "Brett: Ergebnis"
   message $w.e.gast.msg -width 500 -text [lindex $mannschaft($gast) 1]

   pack $w.e.heim.msg -side top -fill x
   pack $w.e.erg.msg -side top -fill x
   pack $w.e.gast.msg -side top -fill x

   set l_heim(1) ""
   set l_gast(1) ""
   set l_ergeb(1) ""
   foreach i [array names l_heim] { set l_heim($i) "" }
   foreach i [array names l_gast] { set l_gast($i) "" }
   foreach i [array names l_ergeb] { set l_ergeb($i) "" }

   # Darstellen Heimspieler
   foreach i [lsort -integer [array names Heimspieler]] {
      frame $w.e.heim.m$i
      checkbutton $w.e.heim.m$i.c -relief flat -variable l_heim($i)
      $w.e.heim.m$i.c deselect
      label $w.e.heim.m$i.s -text $Heimspieler($i)
      pack $w.e.heim.m$i -side top -anchor w
      pack $w.e.heim.m$i.c -side left -anchor w
      pack $w.e.heim.m$i.s -side left -anchor w
   }                                   

   # Darstellen Gastspieler             
   foreach i [lsort -integer [array names Gastspieler]] {
      frame $w.e.gast.m$i
      checkbutton $w.e.gast.m$i.c -relief flat -variable l_gast($i)
      $w.e.gast.m$i.c deselect
      label $w.e.gast.m$i.s -text $Gastspieler($i)
      pack $w.e.gast.m$i -side top -anchor w
      pack $w.e.gast.m$i.c -side left -anchor w
      pack $w.e.gast.m$i.s -side left -anchor w
   }
  
   # Darstellen Bretter
   set s [db_turnier_get Tid Tname Spielnum Spielleiter]
   for {set i 1} { $i <= $Spielnum} { incr i } {
      frame $w.e.erg.m$i
      pack $w.e.erg.m$i -side top
      label $w.e.erg.m$i.brettnr -text $i: 
      entry $w.e.erg.m$i.ergebnis -relief sunken -width 3 \
         -textvariable l_ergeb($i)
      pack $w.e.erg.m$i.brettnr -side left
      pack $w.e.erg.m$i.ergebnis -side left
      bind $w.e.erg.m$i.ergebnis <Double-Button-1> "ui_ergeb_set $i"
   }
                  
   # Laden eventueller Ergebnisse
   set s [db_wettkampf_load $Tid $Runde $wettkampfnr Brettergebnisse]
   if {!$s} { 
      foreach i [lsort -integer [array names Brettergebnisse]] {
         set l_ergeb($i) [lindex $Brettergebnisse($i) 2]
         set k1 [lindex [lindex $Brettergebnisse($i) 0] 1]
         set k2 [lindex [lindex $Brettergebnisse($i) 1] 1]
         $w.e.heim.m$k1.c select
         $w.e.gast.m$k2.c select
      }
   }
   return 0
}               

#============================================================
#
# Procedure: ui_ergeb_set
#
# Purpose: Anzeige und Auswahl mglicher Brettergebnisse
#
# Preconditions: 
#  Brett zeigt auf ein gltiges Brett
# 
# Postconditions:
#  Ein mgliches Ergebnis ist eingetragen
#   Ergebnis kann sein: 1-0, Weiss gewonnen
#                       0-1, Schwarz gewonnen
#                       1/2, Remis
#                       +/-, Weiss gewinnt kampflos
#                       -/+, Schwarz gewinnt kampflos
#                       -/-, Beide Gegner nicht angetreten
#                       ???, Ergebnis unbekannt
#
#
# Globals:
#  l_ergeb(*)
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc ui_ergeb_set { brett } {
   global l_ergeb

   set erg [list "1-0" "0-1" "1/2" "+/-" "-/+" "-/-" "???"]
   set a [tk_dialog .a Einzelergebnis "Brett $brett: Welches Ergebnis?" "" 0 \
          "1-0" "0-1" "1/2" "+/-" "-/+" "-/-" "???" \
         ]
   set l_ergeb($brett) [lindex $erg $a]
}

#============================================================
#
# Procedure: ui_kampflos_set
#
# Purpose: Anzeige und Auswahl mglicher kampfloser Ergebnisse
#
# Preconditions: 
#  spielnum enthaelt die Anzahl der Bretter
# 
# Postconditions:
#  Ein mgliches Ergebnis ist eingetragen
#   Ergebnis kann sein: X-0, Weiss gewonnen
#                       0-X, Schwarz gewonnen
#                       _:_, Wettkampf nicht gespielt
#
#
# Globals:
#  l_kl_ergeb(*)
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================
#--------------------------------------------------------
# Changed:  6-MAY-1997
# Name: G.Niklaus
# Reason: Creation
#-------------------------------------------------------
#--------------------------------------------------------
# Changed:  5-OCT-1997
# Name: G.Niklaus
# Reason: Flexibilisierung auf andere Ergebnisse
#-------------------------------------------------------
                
proc ui_kampflos_set { v spielnum } {
   global l_kl_ergeb

   set erg [list "$spielnum.0 : 0.0" "0.0 : $spielnum.0" "___ - ___"]
   set a [tk_dialog $v.a "Kampfloses Ergebnis" "Welches Ergebnis?" "" 0 \
          "$spielnum.0 : 0.0" "0.0 : $spielnum.0" "___ - ___" \
         ]
   set l_kl_ergeb [lindex $erg $a]
}

#============================================================
# 
# Procedure: ui_tabelle_display
#
# Purpose: Anzeige der Tabelle
#                            
# Preconditions: 
#  Tabelle enthlt korrekte Werte
# 
# Postconditions:
#  Tabelle wird in Window angezeigt
#
# Globals:
#  geom65
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc ui_tabelle_display { Tname Runde ArrayTabelle } {
   global geom65

   upvar $ArrayTabelle Tabelle

   set w .tabelle_display
   catch {destroy $w}
   toplevel $w
   wm title $w "Tabelle nach der $Runde. Runde"
   wm minsize $w 1 1
   message $w.msg1 -text "$Tname" -aspect 500
   message $w.msg2 -text "Tabelle nach der $Runde. Runde" -aspect 500
   pack $w.msg1 $w.msg2 -side top

   frame $w.frame
   scrollbar $w.frame.scrollbar -orient vertical \
       -command "$w.frame.listbox yview"
   set befehl1 "listbox $w.frame.listbox -relief groove "
   set befehl2 "-yscrollcommand {$w.frame.scrollbar set} $geom65"
   eval [concat $befehl1 $befehl2]
   pack $w.frame -side top -expand yes -fill both
   pack $w.frame.scrollbar -side left -fill y
   pack $w.frame.listbox   -side left -fill both -expand yes

   $w.frame.listbox delete 0 end
   set temp "Platz  Mannschaft               S   G   U   V    Bp     Mp"
   $w.frame.listbox insert end $temp
   foreach k [lsort -integer [array names Tabelle]] {
      set temp [format "%4s : %-22s %3s %3s %3s %3s   %5s   %3s" $k \
          [lindex $Tabelle($k) 1] \
          [lindex $Tabelle($k) 2] \
          [lindex $Tabelle($k) 3] \
          [lindex $Tabelle($k) 4] \
          [lindex $Tabelle($k) 5] \
          [lindex $Tabelle($k) 6] \
          [lindex $Tabelle($k) 7] ]
      $w.frame.listbox insert end $temp
   }
}

#============================================================
# 
# Procedure: ui_rangliste_display
#
# Purpose: Anzeige der Rangliste
#
# Preconditions: 
#  Rangliste enthlt korrekte Werte
# 
# Postconditions:
#  Rangliste wird in Window angezeigt
#
# Globals:
#  geom75
#
# Returns:  0 = Success            
#           1 = Fehler
#=============================================================

proc ui_rangliste_display { Tname Runde ArrayRangliste } {
   global geom75

   upvar $ArrayRangliste Rangliste


   set w .rangliste_display
   catch {destroy $w}
   toplevel $w
   wm title $w "Rangliste nach der $Runde. Runde"
   wm minsize $w 1 1
   message $w.msg1 -text "$Tname" -aspect 500
   message $w.msg2 -text "Rangliste nach der $Runde. Runde" -aspect 800
   pack $w.msg1 $w.msg2 -side top

   frame $w.frame
   scrollbar $w.frame.scrollbar -orient vertical \
       -command "$w.frame.listbox yview"
   set befehl1 "listbox $w.frame.listbox -relief groove "
   set befehl2 "-yscrollcommand {$w.frame.scrollbar set} $geom75"
   eval [concat $befehl1 $befehl2]
   pack $w.frame -side top -expand yes -fill both
   pack $w.frame.scrollbar -side left -fill y
   pack $w.frame.listbox   -side left -fill both -expand yes

   $w.frame.listbox delete 0 end
   set temp "Platz  Name                   Mannschaft            Brett  Punkte  Spiele"
   $w.frame.listbox insert end $temp
   foreach k [lsort -integer [array names Rangliste]] {
      set temp [format "%4s : %-22s %-22s  %3s  %5s %6s" $k \
          [lindex $Rangliste($k) 1] \
          [lindex $Rangliste($k) 2] \
          [lindex $Rangliste($k) 0] \
          [lindex $Rangliste($k) 3] \
          [lindex $Rangliste($k) 4] ]
      $w.frame.listbox insert end $temp
   }
   return 0
}
             

